# Generated by roxygen2: do not edit by hand - MODIFIED

export(calibrate)
export(predict_calibratR)
export(reliability_diagramm)
export(statistics_calibratR)
export(visualize_calibratR)
export(getECE)
export(getMCE)
export(build_GUESS)
export(predict_GUESS)
import(foreach)
importFrom(doParallel,registerDoParallel)
importFrom(fitdistrplus,denscomp)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_label)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,scale_color_brewer)
importFrom(ggplot2,scale_color_discrete)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,stat_bin)
importFrom(ggplot2,theme)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(graphics,hist)
importFrom(pROC,roc)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(reshape2,melt)
importFrom(stats,binom.test)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,t.test)
