#' @title example
#' @description list object containing 1) the simulated classifiers for two classes. Distributions are simulated from Gaussian distributions with
#' Normal(mean=1.5, sd=0) for class 1 and Normal(mean=0, sd=0) for class 0 instances. Each class consists of 100 instances.
#' and 2) A test set of 100 instances
#' @name example
#' @format \code{predicted}=vector of 200 simulated classifier values; \code{actual}=their respective true class labels (0/1)
#' @docType data
#' @usage data(example)
#' @keywords datasets
NULL
