% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/example.R
\docType{data}
\name{example}
\alias{example}
\title{example}
\format{\code{predicted}=vector of 200 simulated classifier values; \code{actual}=their respective true class labels (0/1)}
\usage{
data(example)
}
\description{
list object containing 1) the simulated classifiers for two classes. Distributions are simulated from Gaussian distributions with
Normal(mean=1.5, sd=0) for class 1 and Normal(mean=0, sd=0) for class 0 instances. Each class consists of 100 instances.
and 2) A test set of 100 instances
}
\keyword{datasets}
